# SEC03-BP06: Manage access based on life cycle

## Description

Access theo employee lifecycle.

## Implementation Guidance

- Onboarding access automation
- Role change access updates
- Offboarding deprovisioning
- Contractor access expiry
- Leave access suspension

## Risk Level

High - Stale access is a security risk.
